id property
String
get
id
A lower snake_case id of the check, unique in its module, by which a PostGenStep of the module PostGenStep.needs it.
Implementation
String get id;
A lower snake_case id of the check, unique in its module, by which a PostGenStep of the module PostGenStep.needs it.
String get id;