PreflightFailed class final

The check itself could not run, for the reason in message.

Inheritance

Constructors

PreflightFailed(String message)
Creates the result.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
Why the check could not run.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited