constConstructor property
Whether the unnamed constructor must be const, so other code can
create constant instances.
Implementation
final bool constConstructor;
Whether the unnamed constructor must be const, so other code can
create constant instances.
final bool constConstructor;