RoleHookInput<D extends Object> class final

The input of a hook of a role's template or of one of its providers.

Create it with Role.hookInput.

Properties

appIdentity → AppIdentity
The platform identifiers of the app.
no setter
choice → Object?
The result of the role's RoleTemplate.choose hook, or null before it runs or if the role has none.
final
context → ModuleContext
The app being generated.
final
data → List<RoleData<D>>
The data of role that applies in the app, each with its origin, in the order the modules were selected.
final
hashCode → int
The hash code for this object.
no setterinherited
role → Role<D>
The role whose hook runs.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

has(Role<Object> other) → bool
Whether other is present in the app.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited