render method

RoleOutput render(
  1. RoleHookInput<D> input
)

Returns the fragments and brick variables of the module's bricks that depend on the data, such as the routes of a router.

Implementation

RoleOutput render(RoleHookInput<D> input) => const RoleOutput();