paramAnnotations constant

SocketFamily<ParamKey, CodeSocket> const paramAnnotations

Annotations of a parameter of the constructor of a screen, such as auto_route's @PathParam('id').

The template of the screen's feature puts the member's tag in the parameters of the screen's unnamed constructor, right before the parameter, as in {{{smf_router__param_annotations__home__details_screen__id}}} required this.id,. A tag must not follow a {, which mustache would read as part of it: put the parameters on lines of their own.

Implementation

static const paramAnnotations = SocketFamily<ParamKey, CodeSocket>.role(
  routerRole,
  'param_annotations',
  CodeSocket(),
  keyOf: _paramSegments,
  segments: 3,
);