RoutesData class final

The routes a module adds to the app: the data of the RouterRole.

A feature contributes it with routerRole.data(RoutesData([...])). The router puts the routes of a module under the module's namespace, the path /<module id>: the route / of the module home is /home, and its route /settings is /home/settings.

Annotations
  • @immutable

Constructors

RoutesData(List<Route> routes)
Creates the data with the top-level routes of a module.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
routes → List<Route>
The top-level routes of the module, in the order the app lists them.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited