required property

bool required
final

Whether the socket needs at least one contribution, such as a minimum version that the template cannot leave empty.

The owner of the socket's template contributes the base value.

Implementation

final bool required;