FactoryListSocket class final
A socket for a list of function expressions that the owner of the socket
calls: factories, such as () => MyNavigatorObserver(), which it calls
as many times as it needs instances, or listeners, which it calls when
something happens.
It renders the functions as list items, each followed by a comma.
- Inheritance
-
- Object
- SocketKind
- FactoryListSocket
Constructors
- FactoryListSocket()
-
Creates the kind.
const
Properties
- carriesImports → bool
-
Whether contributions to the socket carry Dart imports.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited