ModuleRule<D extends Object> class
final
A check that a role applies, during validation and before anything is rendered, to each module that provides, requires or uses the role.
The pipeline runs the Role.moduleRules with Role.checkModule. For checks of the generated code, see StructuralRule.
Constructors
-
ModuleRule({required String id, required String description, required List<
SmfIssue> check(ModuleRuleInput<D> input)}) -
Creates the rule
idthat runscheck.const
Properties
- description → String
-
What the rule requires, as a sentence.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
A unique id, such as
router.routes_have_screens.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
check(
ModuleRuleInput< D> input) → List<SmfIssue> -
Returns the problems the rule finds in
input. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited