RoleChoiceRequest class final
What the pipeline knows when it runs the RoleTemplate.choose hooks.
Constructors
-
RoleChoiceRequest({required List<
RoleData< data, required Set<Object> >Role< presentRoles, required Map<Object> >String, String?> optionValues, required SmfEnvironment environment, required ModuleContext context}) -
Creates the request.
const
Properties
- context → ModuleContext
-
The app being generated.
final
-
data
→ List<
RoleData< Object> > -
The data of all roles, each with its origin, in the order the modules
were selected.
final
- environment → SmfEnvironment
-
The machine and the user.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
optionValues
→ Map<
String, String?> -
The values of all role options given on the command line, by option
name.
final
-
presentRoles
→ Set<
Role< Object> > -
The roles present in the app.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited