render method
Returns the fragments and brick variables of the module's bricks that depend on the data, such as the routes of a router.
Implementation
RoleOutput render(RoleHookInput<D> input) => const RoleOutput();
Returns the fragments and brick variables of the module's bricks that depend on the data, such as the routes of a router.
RoleOutput render(RoleHookInput<D> input) => const RoleOutput();